==> kubernetes-model-core-5.12.0-sources.jar: io/fabric8/kubernetes/api/model/PersistentVolumeClaimSpecBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PersistentVolumeClaimSpecBuilder extends io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpecFluentImpl<io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpec,io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpecBuilder>{
  public PersistentVolumeClaimSpecBuilder() {
    this(false);
  }
  public PersistentVolumeClaimSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new PersistentVolumeClaimSpec(), validationEnabled);
  }
  public PersistentVolumeClaimSpecBuilder(io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public PersistentVolumeClaimSpecBuilder(io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PersistentVolumeClaimSpec(), validationEnabled);
  }
  public PersistentVolumeClaimSpecBuilder(io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpec instance) {
    this(fluent, instance, false);
  }
  public PersistentVolumeClaimSpecBuilder(io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAccessModes(instance.getAccessModes()); 
    fluent.withDataSource(instance.getDataSource()); 
    fluent.withDataSourceRef(instance.getDataSourceRef()); 
    fluent.withResources(instance.getResources()); 
    fluent.withSelector(instance.getSelector()); 
    fluent.withStorageClassName(instance.getStorageClassName()); 
    fluent.withVolumeMode(instance.getVolumeMode()); 
    fluent.withVolumeName(instance.getVolumeName()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public PersistentVolumeClaimSpecBuilder(io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpec instance) {
    this(instance,false);
  }
  public PersistentVolumeClaimSpecBuilder(io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAccessModes(instance.getAccessModes()); 
    this.withDataSource(instance.getDataSource()); 
    this.withDataSourceRef(instance.getDataSourceRef()); 
    this.withResources(instance.getResources()); 
    this.withSelector(instance.getSelector()); 
    this.withStorageClassName(instance.getStorageClassName()); 
    this.withVolumeMode(instance.getVolumeMode()); 
    this.withVolumeName(instance.getVolumeName()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpec build() {
    PersistentVolumeClaimSpec buildable = new PersistentVolumeClaimSpec(fluent.getAccessModes(),fluent.getDataSource(),fluent.getDataSourceRef(),fluent.getResources(),fluent.getSelector(),fluent.getStorageClassName(),fluent.getVolumeMode(),fluent.getVolumeName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PersistentVolumeClaimSpecBuilder that = (PersistentVolumeClaimSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-core-6.5.1-sources.jar: io/fabric8/kubernetes/api/model/PersistentVolumeClaimSpecBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PersistentVolumeClaimSpecBuilder extends PersistentVolumeClaimSpecFluentImpl<PersistentVolumeClaimSpecBuilder> implements VisitableBuilder<PersistentVolumeClaimSpec,PersistentVolumeClaimSpecBuilder>{
  public PersistentVolumeClaimSpecBuilder() {
    this(false);
  }
  public PersistentVolumeClaimSpecBuilder(Boolean validationEnabled) {
    this(new PersistentVolumeClaimSpec(), validationEnabled);
  }
  public PersistentVolumeClaimSpecBuilder(PersistentVolumeClaimSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public PersistentVolumeClaimSpecBuilder(PersistentVolumeClaimSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PersistentVolumeClaimSpec(), validationEnabled);
  }
  public PersistentVolumeClaimSpecBuilder(PersistentVolumeClaimSpecFluent<?> fluent,PersistentVolumeClaimSpec instance) {
    this(fluent, instance, false);
  }
  public PersistentVolumeClaimSpecBuilder(PersistentVolumeClaimSpecFluent<?> fluent,PersistentVolumeClaimSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAccessModes(instance.getAccessModes()); 
    fluent.withDataSource(instance.getDataSource()); 
    fluent.withDataSourceRef(instance.getDataSourceRef()); 
    fluent.withResources(instance.getResources()); 
    fluent.withSelector(instance.getSelector()); 
    fluent.withStorageClassName(instance.getStorageClassName()); 
    fluent.withVolumeMode(instance.getVolumeMode()); 
    fluent.withVolumeName(instance.getVolumeName()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public PersistentVolumeClaimSpecBuilder(PersistentVolumeClaimSpec instance) {
    this(instance,false);
  }
  public PersistentVolumeClaimSpecBuilder(PersistentVolumeClaimSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAccessModes(instance.getAccessModes()); 
    this.withDataSource(instance.getDataSource()); 
    this.withDataSourceRef(instance.getDataSourceRef()); 
    this.withResources(instance.getResources()); 
    this.withSelector(instance.getSelector()); 
    this.withStorageClassName(instance.getStorageClassName()); 
    this.withVolumeMode(instance.getVolumeMode()); 
    this.withVolumeName(instance.getVolumeName()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  PersistentVolumeClaimSpecFluent<?> fluent;
  Boolean validationEnabled;
  public PersistentVolumeClaimSpec build() {
    PersistentVolumeClaimSpec buildable = new PersistentVolumeClaimSpec(fluent.getAccessModes(),fluent.getDataSource(),fluent.getDataSourceRef(),fluent.getResources(),fluent.getSelector(),fluent.getStorageClassName(),fluent.getVolumeMode(),fluent.getVolumeName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
